
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '33.3.0',
    'branch_nick': 'release-33',
    'revision_id': '9680557705d85a458a9c0b5124f57c917e28517b',
    'revno': 12698
}
